@@ -3,6 +3,7 @@
 
 #include "persistent-data/block.h"
 #include "persistent-data/data-structures/array.h"
+#include "persistent-data/data-structures/bitset.h"
 #include "persistent-data/endian_utils.h"
 #include "persistent-data/space-maps/disk.h"
 #include "persistent-data/transaction_manager.h"
@@ -26,14 +27,30 @@ namespace caching {
 		typedef boost::shared_ptr<metadata> ptr;
 
 		metadata(block_manager<>::ptr bm, open_type ot);
-		metadata(block_manager<>::ptr bm, block_address metadata_snap);
+
+		void commit();
+		void setup_hint_array(size_t width);
+
 
 		typedef persistent_data::transaction_manager tm;
 		tm::ptr tm_;
-		superblock_detail::superblock sb_;
+		superblock sb_;
 		checked_space_map::ptr metadata_sm_;
 		mapping_array::ptr mappings_;
-		//hint_array::ptr hints_;
+		hint_array::ptr hints_;
+		bitset::ptr discard_bits_;
+
+	private:
+		void init_superblock();
+
+		void create_metadata(block_manager<>::ptr bm);
+		void open_metadata(block_manager<>::ptr bm);
+
+		void commit_space_map();
+		void commit_mappings();
+		void commit_hints();
+		void commit_discard_bits();
+		void commit_superblock();
 	};
 };
 
